@@ -404,6 +404,18 @@ class Executor:
             resources = self.job_types.get_resources_for_job(message.job_type)
             result = job_instance.execute(resources=resources, **message.payload)
 
+            if inspect.iscoroutine(result):
+                try:
+                    loop = asyncio.get_event_loop()
+                    if loop.is_closed():
+                        loop = asyncio.new_event_loop()
+                        asyncio.set_event_loop(loop)
+                except RuntimeError:
+                    loop = asyncio.new_event_loop()
+                    asyncio.set_event_loop(loop)
+
+                result = loop.run_until_complete(result)
+
             return Response(
                 id=message.id,
                 success=True,
